@@ -1,21 +1,19 @@
 import threading
 import time
-import heapq
-from threading import Timer
-import random
 # import _thread as thread
 
 TIME_ACCURACY = 1  # 时间精度，时间精度不是越小越好！你的Task每次循环超过了这个值,将影响准确度
 
 
 def IntervalTask(sec, func, params=(), immediatly=True, thread_name=''):
-    def run(params):
+    def run(*params):
         if immediatly is False:
             time.sleep(sec)
         while 1:
             func(*params)
             time.sleep(sec)
 
+    print(params)
     t = threading.Thread(target=run, args=params)
     if thread_name != '':
         t.name = thread_name
@@ -24,7 +22,7 @@ def IntervalTask(sec, func, params=(), immediatly=True, thread_name=''):
 
 
 def normal_task(sec, func, params=(), thread_name=''):
-    def run(params):
+    def run(*params):
         time.sleep(sec)
         func(*params)
 
